@@ -1,5 +1,6 @@
 import math
 from collections import Counter
+import numpy as np
 
 
 def baseline_accuracy(labels):
@@ -22,14 +23,27 @@ def missing_value_percent(df):
     return (df.isna().sum() / num_rows * 100.0).sort_values(ascending=False)
 
 
-def n_clusters(total_rows):
+def na_percent(df):
+    return missing_value_percent(df)
+
+
+def n_clusters(data):
     """
     Generate number of clusters to create.
 
     Heuristic:
     Number of clusters = square root of total data points
 
-    :param total_rows: Total number of data points
+    :param data: Total number of data points or the data point itself
     :return:
     """
+    if type(data) is int:
+        total_rows = data
+    else:
+        total_rows = len(set(data))
     return int(math.sqrt(total_rows))
+
+
+def vector_similarity(u, v):
+    angle = np.dot(u, v) / (np.linalg.norm(u) * np.linalg.norm(v))
+    return float(angle)
